@@ -1,5 +1,3 @@
-import sys
-
 from javonet.core.interpreter.Interpreter import Interpreter
 from javonet.core.protocol.CommandSerializer import CommandSerializer
 from javonet.utils.RuntimeLogger import RuntimeLogger
@@ -9,8 +7,6 @@ from javonet.utils.connectionData.InMemoryConnectionData import InMemoryConnecti
 class Receiver:
 
     def __init__(self):
-        RuntimeLogger.print_runtime_info()
-        sys.stdout.flush()
         self.connection_data = InMemoryConnectionData()
 
     def SendCommand(self, message_byte_array, messageByteArrayLen):
@@ -21,3 +17,6 @@ class Receiver:
         response_byte_array[0] = message_byte_array[11]
         response_byte_array[1] = message_byte_array[12] - 2
         return response_byte_array
+
+    def GetRuntimeInfo(self):
+        return RuntimeLogger().get_runtime_info()
