@@ -3,6 +3,7 @@ use strict;
 use warnings FATAL => 'all';
 use Moose;
 
+use aliased 'Javonet::Sdk::Core::PerlCommand' => 'PerlCommand';
 use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
 use aliased 'Javonet::Core::Interpreter::Interpreter' => 'Interpreter', qw(execute_);
 use aliased 'Javonet::Core::Exception::ExceptionThrower' => 'ExceptionThrower';
@@ -30,28 +31,23 @@ sub new {
     return $self;
 }
 
-DESTROY {
-    my $self = $_[0];
-    if ($self->{current_command}->{command_type} == Javonet::Sdk::Core::PerlCommandType::get_command_type('Reference') &&
-        $self->{isExecuted} == 1) {
-        $self->{current_command} = Javonet::Sdk::Core::PerlCommand->new(
-            runtime      => $self->{runtime_name},
-            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('DestructReference'),
-            payload      => $self->{current_command}->{payload}
-        );
-        $self->execute();
-    }
-}
+# DESTROY {
+#     my $self = $_[0];
+#     if ($self->{current_command}->{command_type} == Javonet::Sdk::Core::PerlCommandType::get_command_type('Reference') &&
+#         $self->{isExecuted} == 1) {
+#         $self->{current_command} = PerlCommand->new(
+#             runtime      => $self->{runtime_name},
+#             command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('DestructReference'),
+#             payload      => $self->{current_command}->{payload}
+#         );
+#         $self->execute();
+#     }
+# }
 
 #@override
 sub execute {
     my $self = $_[0];
-
-    if($self->{current_command}->{runtime} eq Javonet::Sdk::Core::RuntimeLib::get_runtime('Perl')) {
-        $self->{response_command} = $perl_handler->handle_command($self->{current_command});
-    } else {
-        $self->{response_command} = Interpreter->execute_($self->{current_command}, $self->{connection_type}, $self->{tcp_address});
-    }
+    $self->{response_command} = Interpreter->execute_($self->{current_command}, $self->{connection_type}, $self->{tcp_address});
 
     if ($self->{response_command}->{command_type} == Javonet::Sdk::Core::PerlCommandType::get_command_type('Exception')) {
         ExceptionThrower->throwException($self->{response_command})
@@ -76,7 +72,7 @@ sub execute {
 #@override
 sub invoke_instance_method {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeInstanceMethod'),
         payload      => \@arguments
@@ -93,7 +89,7 @@ sub invoke_instance_method {
 #@override
 sub get_instance_field {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetInstanceField'),
         payload      => \@arguments
@@ -110,7 +106,7 @@ sub get_instance_field {
 #@override
 sub set_instance_field {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('SetInstanceField'),
         payload      => \@arguments
@@ -127,7 +123,7 @@ sub set_instance_field {
 #@override
 sub create_instance {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('CreateClassInstance'),
         payload      => \@arguments
@@ -144,7 +140,7 @@ sub create_instance {
 #@override
 sub invoke_static_method {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeStaticMethod'),
         payload      => \@arguments
@@ -165,7 +161,7 @@ sub set_generic_type {
 #@override
 sub get_static_field {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetStaticField'),
         payload      => \@arguments
@@ -182,7 +178,7 @@ sub get_static_field {
 #@override
 sub set_static_field {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('SetStaticField'),
         payload      => \@arguments
@@ -198,7 +194,7 @@ sub set_static_field {
 
 sub get_index {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('ArrayGetItem'),
         payload      => \@arguments
@@ -214,7 +210,7 @@ sub get_index {
 
 sub get_size {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('ArrayGetSize'),
         payload      => \@arguments
@@ -230,7 +226,7 @@ sub get_size {
 
 sub get_rank {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('ArrayGetRank'),
         payload      => \@arguments
@@ -246,7 +242,7 @@ sub get_rank {
 
 sub set_index {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('ArraySetItem'),
         payload      => \@arguments
@@ -262,7 +258,7 @@ sub set_index {
 
 sub invoke_generic_static_method {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeGenericStaticMethod'),
         payload      => \@arguments
@@ -278,7 +274,7 @@ sub invoke_generic_static_method {
 
 sub invoke_generic_method {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('InvokeGenericMethod'),
         payload      => \@arguments
@@ -295,7 +291,7 @@ sub invoke_generic_method {
 #@override
 sub get_enum_name {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumName'),
         payload      => \@arguments
@@ -312,7 +308,7 @@ sub get_enum_name {
 #@override
 sub get_enum_value {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime      => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumValue'),
         payload      => \@arguments
@@ -328,7 +324,7 @@ sub get_enum_value {
 
 sub get_ref_value {
     my ($self, @arguments) = @_;
-    my $command = Javonet::Sdk::Core::PerlCommand->new(
+    my $command = PerlCommand->new(
         runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetRefValue'),
         payload => \@arguments
@@ -340,7 +336,22 @@ sub get_ref_value {
         $self->build_command($command),
         0
     );
+}
 
+sub create_null {
+    my ($self, @arguments) = @_;
+    my $command = PerlCommand->new(
+        runtime      => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('CreateNull'),
+        payload      => \@arguments
+    );
+    return Javonet::Sdk::Internal::InvocationContext->new(
+        $self->{runtime_name},
+        $self->get_connection_type(),
+        $self->get_tcp_address(),
+        $self->build_command($command),
+        0
+    );
 }
 
 sub get_current_command {
@@ -356,9 +367,8 @@ sub get_value {
 
 sub build_command {
     my ($self, $command) = @_;
-    my $command_payload_length = @{$command->{payload}};
-
-    for (my $i = 0; $i < $command_payload_length; $i++) {
+    my $payload_length = @{$command->{payload}};
+    for (my $i = 0; $i < $payload_length; $i++) {
         $command->{payload}[$i] = $self->encapsulate_payload_item($command->{payload}[$i]);
     }
     return $command->prepend_arg_to_payload($self->{current_command});
@@ -366,16 +376,43 @@ sub build_command {
 
 sub encapsulate_payload_item {
     my ($self, $payload_item) = @_;
-    if (blessed($payload_item) and $payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
-        # return Javonet::Sdk::Core::PerlCommand->new(
-        #     runtime      => $self->{runtime_name},
-        #     command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
-        #     payload      => $payload_item->get_current_command(),
-        # );
-        return $payload_item->get_current_command();
-    } else {
+
+    if(!defined $payload_item) {
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+            payload => []
+        );
+    }
+
+    if ($payload_item->isa('Command')) {
+        my $payload_length = @{$payload_item->{payload}};
+        for (my $i = 0; $i < $payload_length; $i++) {
+            $payload_item->{payload}[$i] = $self->encapsulate_payload_item($payload_item->{payload}[$i]);
+        }
         return $payload_item;
     }
+    elsif ($payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
+        return $payload_item->get_current_command();
+    }
+    elsif (ref($payload_item) eq 'ARRAY') {
+        my $payload_length = @$payload_item;
+        for (my $i = 0; $i < $payload_length; $i++) {
+            $payload_item->[$i] = $self->encapsulate_payload_item($payload_item->[$i]);
+        }
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Array'),
+            payload => $payload_item
+        );
+    }
+    else {
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+            payload => [$payload_item]
+        );
+    }
 }
 
 no Moose;
