@@ -2,6 +2,7 @@ package Javonet::Sdk::Internal::RuntimeContext;
 use strict;
 use warnings FATAL => 'all';
 use Moose;
+
 use aliased 'Javonet::Sdk::Core::PerlCommand' => 'PerlCommand';
 use aliased 'Javonet::Sdk::Internal::InvocationContext' => 'InvocationContext';
 use aliased 'Javonet::Core::Handler::PerlHandler' => 'PerlHandler';
@@ -21,7 +22,7 @@ sub new {
     my $class = shift;
 
     my $self = {
-        runtime_lib     => shift,
+        runtime_name     => shift,
         connection_type => shift,
         tcp_address     => shift,
         response_command => 0,
@@ -31,54 +32,51 @@ sub new {
 }
 
 sub get_instance {
-    my $runtime_lib = shift;
+    my $runtime_name = shift;
     my $connection_type = shift;
     my $tcp_address = shift;
     my $path = shift;
 
     if($connection_type eq Javonet::Sdk::Internal::ConnectionType::get_connection_type("InMemory")) {
-        if(exists $memoryRuntimeContexts{$runtime_lib}) {
-            my $runtimeCtx = $memoryRuntimeContexts{$runtime_lib};
+        if(exists $memoryRuntimeContexts{$runtime_name}) {
+            my $runtimeCtx = $memoryRuntimeContexts{$runtime_name};
             $runtimeCtx->{current_command} = undef();
             return $runtimeCtx;
         }
         else {
-            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_lib, $connection_type, '');
-            $memoryRuntimeContexts{$runtime_lib} = $runtimeCtx;
+            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_name, $connection_type, '');
+            $memoryRuntimeContexts{$runtime_name} = $runtimeCtx;
             return($runtimeCtx);
         }
     }
 
     if($connection_type eq Javonet::Sdk::Internal::ConnectionType::get_connection_type("Tcp")) {
-        my $networkRuntimeContextsKey = $runtime_lib . $tcp_address;
+        my $networkRuntimeContextsKey = $runtime_name . $tcp_address;
         if(exists $networkRuntimeContexts{$networkRuntimeContextsKey}) {
             my $runtimeCtx = $networkRuntimeContexts{$networkRuntimeContextsKey};
             $runtimeCtx->{current_command} = undef();
             return $runtimeCtx;
         }
         else {
-            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_lib, $connection_type, $tcp_address);
+            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_name, $connection_type, $tcp_address);
             $networkRuntimeContexts{$networkRuntimeContextsKey} = $runtimeCtx;
             return($runtimeCtx);
         }
     }
 
     if($connection_type eq Javonet::Sdk::Internal::ConnectionType::get_connection_type("WithConfig")) {
-        my $configRuntimeContextsKey = $runtime_lib . $path;
+        my $configRuntimeContextsKey = $runtime_name . $path;
         if(exists $configRuntimeContexts{$configRuntimeContextsKey}) {
             my $runtimeCtx = $configRuntimeContexts{$configRuntimeContextsKey};
             $runtimeCtx->{current_command} = undef();
             return $runtimeCtx;
         }
         else {
-            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_lib, $connection_type, $tcp_address);
+            my $runtimeCtx = Javonet::Sdk::Internal::RuntimeContext->new($runtime_name, $connection_type, $tcp_address);
             $configRuntimeContexts{$configRuntimeContextsKey} = $runtimeCtx;
             return($runtimeCtx);
         }
     }
-
-    
-
 }
 
 
@@ -87,11 +85,7 @@ sub execute {
     my $command = shift;
     my $connection_type = shift;
     my $tcp_address = shift;
-    if($command->{runtime} eq Javonet::Sdk::Core::RuntimeLib::get_runtime('Perl')) {
-        $self->{response_command} = $perl_handler->handle_command($command);
-    } else {
-        $self->{response_command} = Interpreter->execute_($command, $connection_type, $tcp_address);
-    }
+    $self->{response_command} = Interpreter->execute_($command, $connection_type, $tcp_address);
     if ($self->{response_command}->{command_type} == Javonet::Sdk::Core::PerlCommandType::get_command_type('Exception')) {
         ExceptionThrower->throwException($self->{response_command})
     }
@@ -104,12 +98,12 @@ sub load_library {
     my @load_library_parameters = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('LoadLibrary'),
         payload => \@load_library_parameters
     );
 
-    execute($command, $self->{connection_type}, $self->{tcp_address});
+    execute($self->build_command($command), $self->{connection_type}, $self->{tcp_address});
     return $self;
 }
 
@@ -119,13 +113,13 @@ sub get_type {
     my @arguments = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetType'),
         payload => \@arguments
     );
 
     return Javonet::Sdk::Internal::InvocationContext->new(
-        $self->{runtime_lib},
+        $self->{runtime_name},
         $self->{connection_type},
         $self->{tcp_address},
         $self->build_command($command),
@@ -139,13 +133,13 @@ sub cast {
     my @arguments = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Cast'),
         payload => \@arguments
     );
 
     return Javonet::Sdk::Internal::InvocationContext->new(
-        $self->{runtime_lib},
+        $self->{runtime_name},
         $self->{connection_type},
         $self->{tcp_address},
         $self->build_command($command),
@@ -159,13 +153,13 @@ sub get_enum_item {
     my @arguments = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('GetEnumItem'),
         payload => \@arguments
     );
 
     return Javonet::Sdk::Internal::InvocationContext->new(
-        $self->{runtime_lib},
+        $self->{runtime_name},
         $self->{connection_type},
         $self->{tcp_address},
         $self->build_command($command),
@@ -178,13 +172,13 @@ sub as_out {
     my @arguments = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('AsOut'),
         payload => \@arguments
     );
 
     return Javonet::Sdk::Internal::InvocationContext->new(
-        $self->{runtime_lib},
+        $self->{runtime_name},
         $self->{connection_type},
         $self->{tcp_address},
         $self->build_command($command),
@@ -197,13 +191,13 @@ sub as_ref {
     my @arguments = @_;
 
     my $command = PerlCommand->new(
-        runtime => $self->{runtime_lib},
+        runtime => $self->{runtime_name},
         command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('AsRef'),
         payload => \@arguments
     );
 
     return Javonet::Sdk::Internal::InvocationContext->new(
-        $self->{runtime_lib},
+        $self->{runtime_name},
         $self->{connection_type},
         $self->{tcp_address},
         $self->build_command($command),
@@ -214,8 +208,8 @@ sub as_ref {
 #@override
 sub build_command {
     my ($self, $command) = @_;
-    my $command_payload_length = @{$command->{payload}};
-    for (my $i = 0; $i < $command_payload_length; $i++) {
+    my $payload_length = @{$command->{payload}};
+    for (my $i = 0; $i < $payload_length; $i++) {
         $command->{payload}[$i] = $self->encapsulate_payload_item($command->{payload}[$i]);
     }
     return $command->prepend_arg_to_payload($self->{current_command});
@@ -223,11 +217,55 @@ sub build_command {
 
 sub encapsulate_payload_item {
     my ($self, $payload_item) = @_;
-    if ($payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
-        return $payload_item->get_current_command();
-    } else {
+
+    if(!defined $payload_item) {
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+            payload => []
+        );
+    }
+
+    if ($payload_item->isa('Command')) {
+        my $payload_length = @{$payload_item->{payload}};
+        for (my $i = 0; $i < $payload_length; $i++) {
+            $payload_item->{payload}[$i] = $self->encapsulate_payload_item($payload_item->{payload}[$i]);
+        }
         return $payload_item;
     }
+    elsif ($payload_item->isa('Javonet::Sdk::Internal::InvocationContext')) {
+        return $payload_item->get_current_command();
+    }
+    elsif (ref($payload_item) eq 'ARRAY') {
+        my $payload_length = @$payload_item;
+        for (my $i = 0; $i < $payload_length; $i++) {
+            $payload_item->[$i] = $self->encapsulate_payload_item($payload_item->[$i]);
+        }
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Array'),
+            payload => $payload_item
+        );
+    }
+    else {
+        return PerlCommand->new(
+            runtime => $self->{runtime_name},
+            command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+            payload => [$payload_item]
+        );
+    }
+}
+
+sub health_check {
+    my $self = shift;
+
+    my $command = PerlCommand->new(
+        runtime => $self->{runtime_name},
+        command_type => Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'),
+        payload => ['health_check']
+    );
+
+    execute($self->build_command($command), $self->{connection_type}, $self->{tcp_address});
 }
 
 no Moose;
